@@ -29,6 +29,8 @@ import rich.repr
 from rich.console import RenderableType
 from rich.style import Style
 
+from textual.keys import key_to_character
+
 from . import constants, errors, events, messages
 from ._arrange import arrange
 from ._callback import invoke
@@ -189,6 +191,9 @@ class Screen(Generic[ScreenResultType], Widget):
     ALLOW_IN_MAXIMIZED_VIEW: ClassVar[str] = ".-textual-system,Footer"
     """A selector for the widgets (direct children of Screen) that are allowed in the maximized view (in addition to maximized widget)."""
 
+    ESCAPE_TO_MINIMIZE: ClassVar[bool | None] = None
+    """Use escape key to minimize (potentially overriding bindings) or `None` to defer to [`App.ESCAPE_TO_MINIMIZE`][textual.app.App.ESCAPE_TO_MINIMIZE]."""
+
     maximized: Reactive[Widget | None] = Reactive(None, layout=True)
     """The currently maximized widget, or `None` for no maximized widget."""
 
@@ -308,6 +313,7 @@ class Screen(Generic[ScreenResultType], Widget):
     @property
     def _binding_chain(self) -> list[tuple[DOMNode, BindingsMap]]:
         """Binding chain from this screen."""
+
         focused = self.focused
         if focused is not None and focused.loading:
             focused = None
@@ -315,14 +321,24 @@ class Screen(Generic[ScreenResultType], Widget):
 
         if focused is None:
             namespace_bindings = [
-                (self, self._bindings),
-                (self.app, self.app._bindings),
+                (self, self._bindings.copy()),
+                (self.app, self.app._bindings.copy()),
             ]
         else:
             namespace_bindings = [
-                (node, node._bindings) for node in focused.ancestors_with_self
+                (node, node._bindings.copy()) for node in focused.ancestors_with_self
             ]
 
+        # Filter out bindings that could be captures by widgets (such as Input, TextArea)
+        filter_namespaces: list[DOMNode] = []
+        for namespace, bindings_map in namespace_bindings:
+            for filter_namespace in filter_namespaces:
+                check_consume_key = filter_namespace.check_consume_key
+                for key in list(bindings_map.key_to_bindings):
+                    if check_consume_key(key, key_to_character(key)):
+                        del bindings_map.key_to_bindings[key]
+            filter_namespaces.append(namespace)
+
         return namespace_bindings
 
     @property
@@ -346,7 +362,6 @@ class Screen(Generic[ScreenResultType], Widget):
         Returns:
             A map of keys to a tuple containing (NAMESPACE, BINDING, ENABLED).
         """
-
         bindings_map: dict[str, ActiveBinding] = {}
         for namespace, bindings in self._modal_binding_chain:
             for key, binding in bindings:
